@@ -258,7 +258,9 @@ public:
 
     virtual idx_t size() const override { return nb_nodes_; }
 
-    idx_t nb_partitions() const override { return mesh_.nb_partitions(); }
+    idx_t part() const override { return mesh_.part(); }
+
+    idx_t nb_parts() const override { return mesh_.nb_parts(); }
 
     Field lonlat() const override { return nodes_.lonlat(); }
 
@@ -268,12 +270,16 @@ public:
 
     Field remote_index() const override { return nodes_.remote_index(); }
 
+    Field partition() const override { return nodes_.partition(); }
+
     const util::PartitionPolygon& polygon(idx_t halo = 0) const override { return mesh_.polygon(halo); }
 
     const util::PartitionPolygons& polygons() const override { return mesh_.polygons(); }
 
     const Projection& projection() const override { return mesh_.projection(); }
 
+    std::string mpi_comm() const override { return mesh_.mpi_comm(); }
+
 private:  // methods
     void constructor();
 
