@@ -93,7 +93,9 @@ public:
 
     virtual idx_t size() const = 0;
 
-    virtual idx_t nb_partitions() const;
+    virtual idx_t part() const;
+
+    virtual idx_t nb_parts() const;
 
     virtual const util::PartitionPolygon& polygon(idx_t halo = 0) const;
 
@@ -103,12 +105,16 @@ public:
 
     virtual atlas::Field remote_index() const;
 
+    virtual atlas::Field partition() const;
+
     virtual atlas::Field global_index() const;
 
     virtual const util::PartitionPolygons& polygons() const;
 
     virtual const Projection& projection() const;
 
+    virtual std::string mpi_comm() const;
+
 private:
     util::Metadata* metadata_;
 };
