@@ -37,7 +37,7 @@ CellFinder::CellFinder(const Mesh& mesh, const util::Config& config): mesh_{mesh
     auto halo = config.getInt("halo", 0);
     for (idx_t i = 0; i < mesh_.cells().size(); ++i) {
         if (haloView(i) <= halo) {
-            points.emplace_back(PointLonLat(lonlatView(i, LON), lonlatView(i, LAT)));
+            points.emplace_back(lonlatView(i, LON), lonlatView(i, LAT));
             payloads.emplace_back(i);
         }
     }
