@@ -110,9 +110,10 @@ public:
             SRCTGT_INTERSECTPLG_DIFF,    // index, 1/(unit_sphere.area) ( \sum_{scell} scell.area - \sum{tcell} tcell.area )
             REMAP_CONS,  // index, error in mass conservation
             REMAP_L2,    // index, error accuracy for given analytical function
-            REMAP_LINF   // index, like REMAP_L2 but in L_infinity norm
+            REMAP_LINF,  // index, like REMAP_L2 but in L_infinity norm
+            ERRORS_ENUM_SIZE
         };
-        std::array<double, 11> errors;
+        std::array<double, ERRORS_ENUM_SIZE> errors;
 
         double tgt_area_sum;
         double src_area_sum;
