@@ -19,28 +19,29 @@ namespace sparse {
 
 class Backend;
 
-void current_backend( const std::string& backend );
+void current_backend(const std::string& backend);
 sparse::Backend& current_backend();
-sparse::Backend& default_backend( const std::string& backend );
+sparse::Backend& default_backend(const std::string& backend);
 
 
 struct Backend : util::Config {
-    Backend() : util::Config() { set( current_backend() ); }
-    Backend( const std::string type ) : util::Config() { set( default_backend( ( type ) ) ); }
-    Backend( const eckit::Configuration& other );
-    std::string type() const { return getString( "type" ); }
+    Backend(): util::Config() { set(current_backend()); }
+    Backend(const std::string& type);
+    Backend(const eckit::Configuration& other);
+    std::string type() const { return getString("type"); }
     operator std::string() const { return type(); }
+    bool available() const;
 };
 
 namespace backend {
-struct omp : Backend {
-    static std::string type() { return "omp"; }
-    omp() : Backend( type() ) {}
+struct openmp : Backend {
+    static std::string type() { return "openmp"; }
+    openmp(): Backend(type()) {}
 };
 
 struct eckit_linalg : Backend {
     static std::string type() { return "eckit_linalg"; }
-    eckit_linalg() : Backend( type() ) {}
+    eckit_linalg(): Backend(type()) {}
 };
 }  // namespace backend
 
