@@ -63,9 +63,7 @@ CubedSphereDualMeshGenerator::CubedSphereDualMeshGenerator(const eckit::Parametr
 
     // Get partitioner.
     std::string partitioner;
-    try { p.get("partitioner.type", partitioner); } catch( std::exception& ) {}
-    p.get("partitioner", partitioner);
-    if( partitioner.size() ) {
+    if (p.get("partitioner", partitioner) && partitioner.size()) {
         options.set("partitioner", partitioner);
     }
 }
