@@ -74,6 +74,13 @@ public:
     void dirtrans_wind2vordiv(const Field& gpwind, Field& spvor, Field& spdiv,
                               const eckit::Configuration& = util::NoConfig()) const;
 
+    void dirtrans_adj(const Field& spfield, Field& gpfield, const eckit::Configuration& = util::NoConfig()) const;
+
+    void dirtrans_adj(const FieldSet& spfields, FieldSet& gpfields, const eckit::Configuration& = util::NoConfig()) const;
+
+    void dirtrans_wind2vordiv_adj(const Field& spvor, const Field& spdiv, Field& gpwind,
+                                  const eckit::Configuration& = util::NoConfig()) const;
+
     void invtrans(const Field& spfield, Field& gpfield, const eckit::Configuration& = util::NoConfig()) const;
 
     void invtrans(const FieldSet& spfields, FieldSet& gpfields, const eckit::Configuration& = util::NoConfig()) const;
