@@ -1,9 +1,5 @@
 /*
-<<<<<<< HEAD
- * (C) Copyright 1996- ECMWF.
-=======
  * (C) Copyright 2013 ECMWF.
->>>>>>> develop
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
